# Copyright 2022 Guillaume Belanger
# See LICENSE file for licensing details.

from pydantic import BaseModel

from fiveg_core_common_schemas.PlmnId import PlmnId
from fiveg_core_common_schemas.Tac import Tac


class Tai(BaseModel):
    plmnId: PlmnId
    tac: Tac



# Copyright 2022 Guillaume Belanger
# See LICENSE file for licensing details.

from enum import Enum


class N1MessageClass(str, Enum):
    fiveg_mm = "5GMM"
    sm = "SM"
    lpp = "LPP"
    sms = "SMS"
    updp = "UPDP"
    lcs = "LCS"



# Copyright 2022 Guillaume Belanger
# See LICENSE file for licensing details.

from enum import Enum


class AccessType(str, Enum):
    threegpp_access = "3GPP_ACCESS"
    non_threegpp_access = "NON_3GPP_ACCESS"



# Copyright 2022 Guillaume Belanger
# See LICENSE file for licensing details.

from pydantic import BaseModel

from fiveg_core_common_schemas.Uinteger import Uinteger


class Snssai(BaseModel):
    sst: Uinteger
    sd: str



# Copyright 2022 Guillaume Belanger
# See LICENSE file for licensing details.

from pydantic import BaseModel

from fiveg_core_common_schemas.Mcc import Mcc
from fiveg_core_common_schemas.Mnc import Mnc


class PlmnId(BaseModel):
    mcc: Mcc
    mnc: Mnc



# Copyright 2022 Guillaume Belanger
# See LICENSE file for licensing details.

from enum import Enum


class PduSessionType(str, Enum):
    IPV4 = "IPV4"
    IPV6 = "IPV6"
    IPV4V6 = "IPV4V6"
    UNSTRUCTURED = "UNSTRUCTURED"
    ETHERNET = "ETHERNET"



# Copyright 2022 Guillaume Belanger
# See LICENSE file for licensing details.

from enum import Enum


class N2InformationClass(str, Enum):
    sm = "SM"
    nrppa = "NRPPa"
    pws = "PWS"
    pws_bcal = "PWS-BCAL"
    pws_rf = "PWS-RF"
    ran = "RAN"
    v2x = "V2X"



# Copyright 2022 Guillaume Belanger
# See LICENSE file for licensing details.

from enum import Enum


class UriScheme(Enum):
    http = "http"
    https = "https"
    add = "ADD"
    move = "MOVE"
    remove = "REMOVE"
    replace = "REPLACE"
